@@ -25,6 +25,7 @@ class XmlDocToTabular:
         preprocess_doc=None,
         validate=False,
         continue_on_error=False,
+        check_doctype=False,
         log_level=None,
     ):
         if logger:
@@ -41,6 +42,7 @@ class XmlDocToTabular:
         self.preprocess_doc = preprocess_doc
         self.validate = validate
         self.continue_on_error = continue_on_error
+        self.check_doctype = check_doctype
         self.tables = defaultdict(list)
         # lambdas can't be pickled (without dill, at least)
         self.table_pk_idx = defaultdict(partial(defaultdict, int))
@@ -53,9 +55,20 @@ class XmlDocToTabular:
             r"\s+", " ", etree.tostring(xpath_result, method="text", encoding="unicode")
         ).strip()
 
+    def resolve_namespaces_in_xpath(self, expression):
+
+        if "_" in self.ns_map:
+            expression = "/".join(
+                f"_:{_}" if ":" not in _ and _[0] not in "@[" else _
+                for _ in expression.split("/")
+            )
+
+        return expression
+
     def get_pk(self, tree, config):
         def get_pk_component(expression):
-            elems = tree.xpath(expression)
+            expression = self.resolve_namespaces_in_xpath(expression)
+            elems = tree.xpath(expression, namespaces=self.ns_map)
             assert (
                 len(elems) == 1
             ), f"{len(elems)} elements found for <primary_key> component {expression}"
@@ -82,43 +95,68 @@ class XmlDocToTabular:
         """
         return self.process_doc(**payload)
 
+    def do_doctype_check(self, doc, filename, linenum):
+        try:
+            test_doctype(doc, self.config["<root_element>"])
+            return True
+
+        except WrongDoctypeException as exc:
+            self.logger.info(
+                "%s\n%s",
+                colored(
+                    "Unexpected XML document"
+                    + (f" ending at line {linenum}" if linenum else "")
+                    + (f" in file {filename}" if filename else "")
+                    + ": ",
+                    "yellow",
+                ),
+                str(exc),
+            )
+
+            if not self.continue_on_error:
+                raise
+
+            return False
+
+        except NoDoctypeException:
+            self.logger.info(
+                "%s\n",
+                colored(
+                    "Document"
+                    + (f" ending at line {linenum}" if linenum and linenum > -1 else "")
+                    + (f" in file {filename}" if filename else "")
+                    + " has no DOCTYPE:",
+                    "yellow",
+                ),
+            )
+
+            if not self.continue_on_error:
+                raise
+
+            return False
+
     def process_doc(self, doc, filename=None, linenum=None):
-
-        if "xml_root" in self.config:
-            try:
-                test_doctype(doc, self.config["xml_root"])
-
-            except WrongDoctypeException as exc:
-                self.logger.debug(
-                    "%s\n%s",
-                    colored(
-                        "Unexpected XML document"
-                        + (f" ending at line {linenum}" if linenum else "")
-                        + (f" in file {filename}" if filename else "")
-                        + ": ",
-                        "yellow",
-                    ),
-                    str(exc),
-                )
-                return self.tables
-
-            except NoDoctypeException:
-                self.logger.debug(
-                    "%s\n%s",
-                    colored(
-                        "Document"
-                        + (f" ending at line {linenum}" if linenum else "")
-                        + (f" in file {filename}" if filename else "")
-                        + " has no DOCTYPE:",
-                        "yellow",
-                    ),
-                    doc,
-                )
-                return self.tables
+        if self.check_doctype and not self.do_doctype_check(doc, filename, linenum):
+            # doctype check failed, but continue_on_error is True
+            return self.tables
 
         try:
             tree = self.parse_tree(doc)
+
+            try:
+                tree = tree.getroot()
+            except AttributeError:
+                pass
+
+            if self.__dict__.get("ns_map", None) is None:
+                self.ns_map = {
+                    k if k is not None else "_": v for k, v in tree.nsmap.items()
+                }
+                self.ns_map_reversed = {v: k for k, v in self.ns_map.items()}
+
             for path, config in self.config.items():
+                if path == "<root_element>":
+                    continue
                 self.process_path(tree, path, config, filename, {})
 
         except LookupError as exc:
@@ -186,15 +224,19 @@ class XmlDocToTabular:
     def process_path(
         self, tree, path, config, filename, record, parent_entity=None, parent_pk=None
     ):
-        try:
-            tree = tree.getroot()
-        except AttributeError:
-            pass
+        path = self.resolve_namespaces_in_xpath(path)
+        tag = tree.tag
+        if self.ns_map:
+            tag = re.sub(
+                r"^{([^}]+)}",
+                lambda m: f"{self.ns_map_reversed[m.group(1)]}:",
+                tree.tag,
+            )
 
-        if path == tree.tag:
+        if path == tag:
             results = [tree]
         else:
-            results = tree.xpath(path)
+            results = tree.xpath(path, namespaces=self.ns_map)
             if len(results) > 1 and not any(
                 key in config
                 for key in ("<entity>", "<joiner>", "<enum_map>", "<enum_type>")
@@ -209,13 +251,12 @@ class XmlDocToTabular:
 
         for result in results:
             self.process_field(
-                result, path, config, filename, record, parent_entity, parent_pk
+                result, config, filename, record, parent_entity, parent_pk
             )
 
     def process_field(
         self,
         result,
-        path,
         config,
         filename,
         record,
@@ -263,7 +304,6 @@ class XmlDocToTabular:
             for subconfig in config:
                 self.process_field(
                     result,
-                    path,
                     subconfig,
                     filename,
                     record,
